==> mingw-w64-starpu-1.4.7-3.src.tar.zst: starpu-1.4.7/doc/doxygen_web_performances/html_web_performances/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Performances", "index.html", [
    [ "Benchmarking StarPU", "BenchmarkingStarPU.html", [
      [ "Task Size Overhead", "BenchmarkingStarPU.html#TaskSizeOverhead", null ],
      [ "Data Transfer Latency", "BenchmarkingStarPU.html#DataTransferLatency", null ],
      [ "Matrix-Matrix Multiplication", "BenchmarkingStarPU.html#MatrixMatrixMultiplication", null ],
      [ "Cholesky Factorization", "BenchmarkingStarPU.html#CholeskyFactorization", null ],
      [ "LU Factorization", "BenchmarkingStarPU.html#LUFactorization", null ],
      [ "Simulated Benchmarks", "BenchmarkingStarPU.html#SimulatedBenchmarks", null ]
    ] ],
    [ "Online Performance Tools", "OnlinePerformanceTools.html", [
      [ "On-line Performance Feedback", "OnlinePerformanceTools.html#On-linePerformanceFeedback", [
        [ "Enabling On-line Performance Monitoring", "OnlinePerformanceTools.html#EnablingOn-linePerformanceMonitoring", null ],
        [ "Per-task Feedback", "OnlinePerformanceTools.html#Per-taskFeedback", null ],
        [ "Per-codelet Feedback", "OnlinePerformanceTools.html#Per-codeletFeedback", null ],
        [ "Per-worker Feedback", "OnlinePerformanceTools.html#Per-workerFeedback", null ],
        [ "Bus-related Feedback", "OnlinePerformanceTools.html#Bus-relatedFeedback", null ],
        [ "MPI-related Feedback", "OnlinePerformanceTools.html#MPI-relatedFeedback", null ]
      ] ],
      [ "Task And Worker Profiling", "OnlinePerformanceTools.html#TaskAndWorkerProfiling", null ],
      [ "Performance Model Example", "OnlinePerformanceTools.html#PerformanceModelExample", null ],
      [ "Performance Monitoring Counters", "OnlinePerformanceTools.html#PerformanceMonitoringCounters", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfMonCountObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfMonCountEntities", [
          [ "Performance Counter", "OnlinePerformanceTools.html#PerfMonCountCounter", null ],
          [ "Performance Counter Type", "OnlinePerformanceTools.html#PerfMonCountCounterType", null ],
          [ "Performance Counter Scope", "OnlinePerformanceTools.html#PerfMonCountCounterScope", null ],
          [ "Performance Counter Set", "OnlinePerformanceTools.html#PerfMonCountCounterSet", null ],
          [ "Performance Counter Sample", "OnlinePerformanceTools.html#PerfMonCountCounterSample", null ],
          [ "Performance Counter Listener", "OnlinePerformanceTools.html#PerfMonCountCounterListener", null ],
          [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfMonCountCounterAPI", null ]
        ] ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfMonCountCounterImplementation", [
          [ "Performance Counter Registration", "OnlinePerformanceTools.html#PerfMonCountCounterImplRegistration", null ],
          [ "Performance Sample Updaters", "OnlinePerformanceTools.html#PerfMonCountCounterImplUpdaters", null ],
          [ "Counter operations", "OnlinePerformanceTools.html#PerfMonCountCounterImplOperations", null ],
          [ "Runtime checks", "OnlinePerformanceTools.html#PerfMonCountCounterImplRuntime", null ]
        ] ],
        [ "Exported Counters", "OnlinePerformanceTools.html#PerfMonCountCounterExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerWorker", null ],
          [ "Per-Codelet Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerCodelet", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfMonCountCounterSequence", null ]
      ] ],
      [ "Performance Steering Knobs", "OnlinePerformanceTools.html#PerfKnobs", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfKnobsObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfKnobsEntities", [
          [ "Performance Steering Knob", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnob", null ],
          [ "Knob Type", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobType", null ],
          [ "Knob Scope", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobScope", null ],
          [ "Knob Group", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobGroup", null ]
        ] ],
        [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfKnobsAPI", null ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfKnobsImpl", null ],
        [ "Exported Steering Knobs", "OnlinePerformanceTools.html#PerfKnobsExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfKnobsExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerWorker", null ],
          [ "Per-Scheduler Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerScheduler", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfKnobsSequence", null ]
      ] ]
    ] ],
    [ "Offline Performance Tools", "OfflinePerformanceTools.html", [
      [ "Generating Traces With FxT", "OfflinePerformanceTools.html#GeneratingTracesWithFxT", [
        [ "Creating a Gantt Diagram", "OfflinePerformanceTools.html#CreatingAGanttDiagram", [
          [ "Zooming in Gantt Diagram", "OfflinePerformanceTools.html#ZoomingInGantt", null ],
          [ "Colors in Gantt Diagram", "OfflinePerformanceTools.html#ColorsInGantt", null ],
          [ "Curves in Gantt Diagram", "OfflinePerformanceTools.html#CurvesInGantt", null ],
          [ "States in Gantt Diagram", "OfflinePerformanceTools.html#StatesInGantt", null ],
          [ "Transfers in Gantt Diagram", "OfflinePerformanceTools.html#TransfersInGantt", null ],
          [ "Scheduler in Gantt Diagram", "OfflinePerformanceTools.html#SchedulerInGantt", null ],
          [ "Main Thread in Gantt Diagram", "OfflinePerformanceTools.html#MainThreadInGantt", null ],
          [ "Statistics in Gantt Diagram", "OfflinePerformanceTools.html#StatisticsInGantt", null ]
        ] ],
        [ "Creating a DAG With Graphviz", "OfflinePerformanceTools.html#CreatingADAGWithGraphviz", null ],
        [ "Getting Task Details", "OfflinePerformanceTools.html#TraceTaskDetails", null ],
        [ "Getting Scheduling Task Details", "OfflinePerformanceTools.html#TraceSchedTaskDetails", null ],
        [ "Monitoring Activity", "OfflinePerformanceTools.html#MonitoringActivity", null ],
        [ "Getting Modular Schedular Animation", "OfflinePerformanceTools.html#Animation", null ],
        [ "Analyzing Time Between MPI Data Transfer and Use by Tasks", "OfflinePerformanceTools.html#TimeBetweenSendRecvDataUse", null ],
        [ "Number of events in trace files", "OfflinePerformanceTools.html#NumberEvents", null ],
        [ "Limiting The Scope Of The Trace", "OfflinePerformanceTools.html#LimitingScopeTrace", null ]
      ] ],
      [ "Performance Of Codelets", "OfflinePerformanceTools.html#PerformanceOfCodelets", null ],
      [ "Energy Of Codelets", "OfflinePerformanceTools.html#EnergyOfCodelets", null ],
      [ "Data trace and tasks length", "OfflinePerformanceTools.html#DataTrace", null ],
      [ "Trace Statistics", "OfflinePerformanceTools.html#TraceStatistics", null ],
      [ "PAPI counters", "OfflinePerformanceTools.html#PapiCounters", null ],
      [ "Theoretical Lower Bound On Execution Time", "OfflinePerformanceTools.html#TheoreticalLowerBoundOnExecutionTime", null ],
      [ "Trace visualization with StarVZ", "OfflinePerformanceTools.html#starvz", null ],
      [ "StarPU Eclipse Plugin", "OfflinePerformanceTools.html#EclipsePlugin", [
        [ "Eclipse Installation", "OfflinePerformanceTools.html#EclipseInstallation", null ],
        [ "StarPU Eclipse Plugin Compilation and Installation", "OfflinePerformanceTools.html#PluginInstallation", null ],
        [ "StarPU Eclipse Plugin Instruction", "OfflinePerformanceTools.html#PluginInstruction", null ]
      ] ],
      [ "Memory Feedback", "OfflinePerformanceTools.html#MemoryFeedback", null ],
      [ "Data Statistics", "OfflinePerformanceTools.html#DataStatistics", null ],
      [ "Tracing MPI applications", "OfflinePerformanceTools.html#TraceMpi", null ],
      [ "Verbose Traces", "OfflinePerformanceTools.html#VerboseTraces", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BenchmarkingStarPU.html",
"group__API__Codelet__And__Tasks.html#a593418a8961318e4085177abeeaa43ad",
"group__API__Data__Interfaces.html#a99f4a2889d2184c091620140fa517e37",
"group__API__Data__Interfaces.html#gadcf7063b1cd8d0feed7054e6e4d9d217",
"group__API__Explicit__Dependencies.html#gabaef95d742d03c96453905602e511050",
"group__API__Interop__Support.html#ga8a6b1a42180b3e601e891d726dcf4997",
"group__API__Modularized__Scheduler.html#ga699b31664bb3665f25ef360c2512d8f9",
"group__API__Parallel__Tasks.html#gaf99bc08bf6f586b658febdd1dc6fef80",
"group__API__Profiling.html#a78e32404bdff71292562d2dc5892061c",
"group__API__Scheduling__Contexts.html#gaeb43bd3c56edb4bc4590eecc4eae76f0",
"group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808",
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__nchildren.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__min__priority__is__set.html",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__req__free.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.9-2.src.tar.zst: starpu-1.4.9/doc/doxygen_web_performances/html_web_performances/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Performances", "index.html", [
    [ "Benchmarking StarPU", "BenchmarkingStarPU.html", [
      [ "Task Size Overhead", "BenchmarkingStarPU.html#TaskSizeOverhead", null ],
      [ "Data Transfer Latency", "BenchmarkingStarPU.html#DataTransferLatency", null ],
      [ "Matrix-Matrix Multiplication", "BenchmarkingStarPU.html#MatrixMatrixMultiplication", null ],
      [ "Cholesky Factorization", "BenchmarkingStarPU.html#CholeskyFactorization", null ],
      [ "LU Factorization", "BenchmarkingStarPU.html#LUFactorization", null ],
      [ "Simulated Benchmarks", "BenchmarkingStarPU.html#SimulatedBenchmarks", null ]
    ] ],
    [ "Online Performance Tools", "OnlinePerformanceTools.html", [
      [ "On-line Performance Feedback", "OnlinePerformanceTools.html#On-linePerformanceFeedback", [
        [ "Enabling On-line Performance Monitoring", "OnlinePerformanceTools.html#EnablingOn-linePerformanceMonitoring", null ],
        [ "Per-task Feedback", "OnlinePerformanceTools.html#Per-taskFeedback", null ],
        [ "Per-codelet Feedback", "OnlinePerformanceTools.html#Per-codeletFeedback", null ],
        [ "Per-worker Feedback", "OnlinePerformanceTools.html#Per-workerFeedback", null ],
        [ "Bus-related Feedback", "OnlinePerformanceTools.html#Bus-relatedFeedback", null ],
        [ "MPI-related Feedback", "OnlinePerformanceTools.html#MPI-relatedFeedback", null ]
      ] ],
      [ "Task And Worker Profiling", "OnlinePerformanceTools.html#TaskAndWorkerProfiling", null ],
      [ "Performance Model Example", "OnlinePerformanceTools.html#PerformanceModelExample", null ],
      [ "Performance Monitoring Counters", "OnlinePerformanceTools.html#PerformanceMonitoringCounters", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfMonCountObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfMonCountEntities", [
          [ "Performance Counter", "OnlinePerformanceTools.html#PerfMonCountCounter", null ],
          [ "Performance Counter Type", "OnlinePerformanceTools.html#PerfMonCountCounterType", null ],
          [ "Performance Counter Scope", "OnlinePerformanceTools.html#PerfMonCountCounterScope", null ],
          [ "Performance Counter Set", "OnlinePerformanceTools.html#PerfMonCountCounterSet", null ],
          [ "Performance Counter Sample", "OnlinePerformanceTools.html#PerfMonCountCounterSample", null ],
          [ "Performance Counter Listener", "OnlinePerformanceTools.html#PerfMonCountCounterListener", null ],
          [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfMonCountCounterAPI", null ]
        ] ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfMonCountCounterImplementation", [
          [ "Performance Counter Registration", "OnlinePerformanceTools.html#PerfMonCountCounterImplRegistration", null ],
          [ "Performance Sample Updaters", "OnlinePerformanceTools.html#PerfMonCountCounterImplUpdaters", null ],
          [ "Counter operations", "OnlinePerformanceTools.html#PerfMonCountCounterImplOperations", null ],
          [ "Runtime checks", "OnlinePerformanceTools.html#PerfMonCountCounterImplRuntime", null ]
        ] ],
        [ "Exported Counters", "OnlinePerformanceTools.html#PerfMonCountCounterExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerWorker", null ],
          [ "Per-Codelet Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerCodelet", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfMonCountCounterSequence", null ]
      ] ],
      [ "Performance Steering Knobs", "OnlinePerformanceTools.html#PerfKnobs", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfKnobsObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfKnobsEntities", [
          [ "Performance Steering Knob", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnob", null ],
          [ "Knob Type", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobType", null ],
          [ "Knob Scope", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobScope", null ],
          [ "Knob Group", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobGroup", null ]
        ] ],
        [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfKnobsAPI", null ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfKnobsImpl", null ],
        [ "Exported Steering Knobs", "OnlinePerformanceTools.html#PerfKnobsExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfKnobsExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerWorker", null ],
          [ "Per-Scheduler Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerScheduler", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfKnobsSequence", null ]
      ] ]
    ] ],
    [ "Offline Performance Tools", "OfflinePerformanceTools.html", [
      [ "Generating Traces With FxT", "OfflinePerformanceTools.html#GeneratingTracesWithFxT", [
        [ "Creating a Gantt Diagram", "OfflinePerformanceTools.html#CreatingAGanttDiagram", [
          [ "Zooming in Gantt Diagram", "OfflinePerformanceTools.html#ZoomingInGantt", null ],
          [ "Colors in Gantt Diagram", "OfflinePerformanceTools.html#ColorsInGantt", null ],
          [ "Curves in Gantt Diagram", "OfflinePerformanceTools.html#CurvesInGantt", null ],
          [ "States in Gantt Diagram", "OfflinePerformanceTools.html#StatesInGantt", null ],
          [ "Transfers in Gantt Diagram", "OfflinePerformanceTools.html#TransfersInGantt", null ],
          [ "Scheduler in Gantt Diagram", "OfflinePerformanceTools.html#SchedulerInGantt", null ],
          [ "Main Thread in Gantt Diagram", "OfflinePerformanceTools.html#MainThreadInGantt", null ],
          [ "Statistics in Gantt Diagram", "OfflinePerformanceTools.html#StatisticsInGantt", null ]
        ] ],
        [ "Creating a DAG With Graphviz", "OfflinePerformanceTools.html#CreatingADAGWithGraphviz", null ],
        [ "Getting Task Details", "OfflinePerformanceTools.html#TraceTaskDetails", null ],
        [ "Getting Scheduling Task Details", "OfflinePerformanceTools.html#TraceSchedTaskDetails", null ],
        [ "Monitoring Activity", "OfflinePerformanceTools.html#MonitoringActivity", null ],
        [ "Getting Modular Schedular Animation", "OfflinePerformanceTools.html#Animation", null ],
        [ "Analyzing Time Between MPI Data Transfer and Use by Tasks", "OfflinePerformanceTools.html#TimeBetweenSendRecvDataUse", null ],
        [ "Number of events in trace files", "OfflinePerformanceTools.html#NumberEvents", null ],
        [ "Limiting The Scope Of The Trace", "OfflinePerformanceTools.html#LimitingScopeTrace", null ]
      ] ],
      [ "Performance Of Codelets", "OfflinePerformanceTools.html#PerformanceOfCodelets", null ],
      [ "Energy Of Codelets", "OfflinePerformanceTools.html#EnergyOfCodelets", null ],
      [ "Data trace and tasks length", "OfflinePerformanceTools.html#DataTrace", null ],
      [ "Trace Statistics", "OfflinePerformanceTools.html#TraceStatistics", null ],
      [ "PAPI counters", "OfflinePerformanceTools.html#PapiCounters", null ],
      [ "Theoretical Lower Bound On Execution Time", "OfflinePerformanceTools.html#TheoreticalLowerBoundOnExecutionTime", null ],
      [ "Trace visualization with StarVZ", "OfflinePerformanceTools.html#starvz", null ],
      [ "StarPU Eclipse Plugin", "OfflinePerformanceTools.html#EclipsePlugin", [
        [ "Eclipse Installation", "OfflinePerformanceTools.html#EclipseInstallation", null ],
        [ "StarPU Eclipse Plugin Compilation and Installation", "OfflinePerformanceTools.html#PluginInstallation", null ],
        [ "StarPU Eclipse Plugin Instruction", "OfflinePerformanceTools.html#PluginInstruction", null ]
      ] ],
      [ "Memory Feedback", "OfflinePerformanceTools.html#MemoryFeedback", null ],
      [ "Data Statistics", "OfflinePerformanceTools.html#DataStatistics", null ],
      [ "Tracing MPI applications", "OfflinePerformanceTools.html#TraceMpi", null ],
      [ "Verbose Traces", "OfflinePerformanceTools.html#VerboseTraces", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BenchmarkingStarPU.html",
"group__API__Codelet__And__Tasks.html#a52e061fbdb64f2e48569951ca4b253be",
"group__API__Data__Interfaces.html#a975914df540caa34fd0f469d242e3a40",
"group__API__Data__Interfaces.html#gada534736df809f642437792b1acd7af8",
"group__API__Explicit__Dependencies.html#ga863d71b775ec517493f81e731a64d134",
"group__API__Interop__Support.html#ga6e3313ab94d5bef08fbdf87672a9c699",
"group__API__Modularized__Scheduler.html#ga5c4ea8cd11d331eb39de2c02ce29efb1",
"group__API__Parallel__Tasks.html#ga5b81d2b58b724e33b7fcbb546464510a",
"group__API__Profiling.html#a650860076a4d4c07929e97ec64386724",
"group__API__Scheduling__Contexts.html#gae3437dfe9f125233c25bf58c9c6f87d7",
"group__API__Workers.html#ab92e3de048f56a4c2f59fa804594c339",
"interfacefstarpu__mod_1_1fstarpu__data__filter__set__filter__func.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__list__task__counters__reset__all.html",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__redux__data.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
